Element

Struct Element 

pub struct Element<'a, Message, Theme, Renderer> { /* private fields */ }
Available on crate feature advanced only.
A generic Widget.

It is useful to build composable user interfaces that do not leak implementation details in their view logic.

If you have any Widget, you should be able to use Widget::boxed to turn it into an Element.